@@ -12,6 +12,6 @@ echo "PostgreSQL started."
 # Apply migrations
 python manage.py migrate
 
-echo "Command to execute: $@"
+# echo "Command to execute: $@"
 # Start your Django app (you can modify this if you use a different command to start your app)
 exec "$@"
