@@ -8,6 +8,10 @@ from django.conf import settings
 import requests
 import time
 import os
+import tempfile
+import subprocess
+import shutil
+import uuid
 
 if TYPE_CHECKING:
     from unicom.models import Channel
@@ -18,6 +22,7 @@ def send_telegram_message(channel: Channel, params: dict, user: User=None, retry
     Params must include at least chat_id and text (if sending a text message or caption).
     If 'type' == 'audio', we send an audio file.
     If 'type' == 'image', we send a photo, with optional caption in 'text'.
+    If 'reply_markup' is provided, it will be sent as inline keyboard buttons.
     """
     if not "parse_mode" in params:
         params["parse_mode"] = "Markdown"
@@ -33,10 +38,22 @@ def send_telegram_message(channel: Channel, params: dict, user: User=None, retry
         msg_type = params['type']
         # Sending audio
         if msg_type == 'audio':
-            url = f"https://api.telegram.org/bot{TELEGRAM_API_TOKEN}/sendAudio"
-            files = {"audio": open(params['file_path'], 'rb')}
-            params.pop('file_path', None)
-            params.pop('type', None)
+            file_path = params['file_path']
+            ext = os.path.splitext(file_path)[-1].lower()
+            if ext in ['.oga', '.ogg']:
+                url = f"https://api.telegram.org/bot{TELEGRAM_API_TOKEN}/sendVoice"
+                files = {"voice": open(file_path, 'rb')}
+                # Store audio_id before popping file_path
+                audio_id = params.get('audio_id')
+                params.pop('file_path', None)
+                params.pop('type', None)
+            else:
+                url = f"https://api.telegram.org/bot{TELEGRAM_API_TOKEN}/sendAudio"
+                files = {"audio": open(file_path, 'rb')}
+                # Store audio_id before popping file_path
+                audio_id = params.get('audio_id')
+                params.pop('file_path', None)
+                params.pop('type', None)
 
         # Sending image
         elif msg_type == 'image':
@@ -66,11 +83,42 @@ def send_telegram_message(channel: Channel, params: dict, user: User=None, retry
 
     retries = 0
     while retries <= max_retries:
-        print(f"Attempt {retries} to send telegram message")
-        response = requests.post(url, data=params, files=files)
+        print(f"DEBUG: Attempt {retries} to send telegram message with params: {params}")
+
+        # Convert reply_markup to JSON string for the API call if it exists
+        request_params = params.copy()
+        if 'reply_markup' in request_params:
+            import json
+            request_params['reply_markup'] = json.dumps(request_params['reply_markup'])
+
+        response = requests.post(url, data=request_params, files=files)
         ret = response.json()
 
         if ret.get('ok'):
+            # Preserve audio_id if it exists
+            if msg_type == 'audio' and 'audio_id' in locals():
+                ret['result']['audio_id'] = audio_id
+            # If media was sent, ensure the file is saved to media folder and pass its path
+            # locals() returns a dictionary of the current local symbol table, containing all local variables.
+            # Here we check if 'file_path' exists as a local variable in the current function scope
+            if 'type' in params and 'file_path' in locals():
+                msg_type = params['type']
+                if msg_type in ['audio', 'image']:
+                    # Save a copy to media folder if not already there
+                    orig_path = file_path
+                    # If not already in media folder, copy it
+                    if not orig_path.startswith('media/'):
+                        ext = os.path.splitext(orig_path)[-1]
+                        new_name = f"{uuid.uuid4()}{ext}"
+                        dest_path = os.path.join(settings.MEDIA_ROOT, 'media', new_name)
+                        os.makedirs(os.path.dirname(dest_path), exist_ok=True)
+                        shutil.copy2(orig_path, dest_path)
+                        media_file_path = f"media/{new_name}"
+                    else:
+                        media_file_path = orig_path
+                    # Add to result dict for save_telegram_message
+                    ret['result']['media_file_path'] = media_file_path
+            
             return save_telegram_message(channel, ret.get('result'), user)
         elif 'error_code' in ret and ret['error_code'] == 429:  # Rate limit
             time.sleep(retry_interval)
